@@ -90,10 +90,12 @@ colorPalette <- function(name,
         "gogh", "house", "jasp",
         "jfa", "jungle", "klimt",
         "kpd", "lava", "nature",
+        "neo1", "neo2", "neo3",
         "mixer1", "mixer2", "mixer3",
         "mixer4", "neon1", "neon2",
         "origami", "retro1", "retro2",
-        "retro3", "retro4", "sooph",
+        "retro3", "retro4", "shell1",
+        "shell2", "shell3", "sooph",
         "sky", "tuscany1", "tuscany2",
         "tuscany3", "vrolik1", "vrolik2",
         "vrolik3", "vrolik4", "vrolik5"
@@ -120,11 +122,14 @@ colorPalette <- function(name,
       "klimt" = c("#847049", "#ba9d3e", "#29241f", "#a787b0", "#cd5627", "#7ea36e"),
       "kpd" = c("#c42f32", "#315b99", "#354741"),
       "lava" = c("#f59907", "#a42300", "#482a22", "#050000", "#6b0800"),
+      "nature" = c("forestgreen", "dodgerblue", "brown", "white", "gray"),
+      "neo1" = c("#de3070", "#89fb68", "#84e7fa", "#6b9cc4", "#090F22"),
+      "neo2" = c("#7dfa6a", "#dafd6a", "#eeb556", "#e93d54", "#ad2456"),
+      "neo3" = c("#de4a27", "#ed7a30", "#f7cf46", "#1735e4", "#0c259c"),
       "mixer1" = c("#fa9f29", "#15cab1", "#0a633d", "#2f3030"),
       "mixer2" = c("#a3a948", "#edb92e", "#f85931", "#ce1836", "#009989"),
       "mixer3" = c("#aacad5", "#c9e0e6", "#e0e9ee", "#dccda4", "#99886e"),
       "mixer4" = c("#20663F", "#259959", "#ABD406", "#FFD412", "#FF821C"),
-      "nature" = c("forestgreen", "dodgerblue", "brown", "white", "gray"),
       "neon1" = c("#F7FD04", "#F9B208", "#F98404", "#FC5404"),
       "neon2" = c("#F5F7B2", "#1CC5DC", "#890596", "#CF0000"),
       "origami" = c("#01364f", "#84231e", "#247c86", "#e8674d", "#dfdbbe", "#fdf4b4"),
@@ -132,6 +137,9 @@ colorPalette <- function(name,
       "retro2" = c("#DDDDDD", "#222831", "#30475E", "#F05454"),
       "retro3" = c("#111D5E", "#C70039", "#F37121", "#C0E218"),
       "retro4" = c("#80A8A8", "#909D9E", "#A88C8C", "#FF0D51"),
+      "shell1" = c("#D6D0C0", "#1C2328", "#A1ABC4", "#8A847A"),
+      "shell2" = c("#2B1E1E", "#6E3623", "#292D2F", "#E4F3F5", "#D8BBA2"),
+      "shell3" = c("#B9CDDD", "#D4D5CE", "#44596F", "#495152", "#7CADD6"),
       "sooph" = c("#d6c398", "#cbabdb", "#139485", "#9e1710", "#414952"),
       "sky" = c("#CFF09E", "#A8DBA8", "#79BD9A", "#3B8686", "#0B486B"),
       "tuscany1" = c("firebrick", "goldenrod", "forestgreen", "navyblue"),
